import express from 'express';

import utils from './utils.mjs';
import db from './db.mjs';

// server

const router = express.Router();

export default router;

router.use(express.json());

// POST

router.post('/:site/*', utils.limiter(20), (req, res) => {
    const site = req.params.site;
    const path = req.params[0];

    if (!req.body.token || !req.body.message) {
        res.status(400).json("הודעה ריקה.");
        return;
    }

    let object = {
        user: utils.escapeHtml(req.body.name) || "Anonymous",
        user_website: utils.escapeHtml(req.body.website) || null,
        message: utils.escapeHtml(req.body.message),
        reply_to: req.body.reply_to || null,
        site,
        path,
    };

    // validation
    const user_token = req.body.token;
    const site_info = db.siteInfo(site);
    console.log(site_info.comment_token, site_info.message_length_limit);

    if (user_token !== site_info.comment_token) {
        res.status(403).json("תשובת סינון שגויה.");
    } else if (object.user.length > utils.MAX_LENGTHS.username) {
        res.status(400).json("שם משתמש ארוך מדי.");
    } else if (object.user_website > utils.MAX_LENGTHS.user_website) {
        res.status(400).json("כתובת אתר ארוכה מדי.");
    } else if (object.message > site_info.message_length_limit) {
        res.status(400).json("הודעה ארוכה מדי.");
    } else {
        const comment = db.insertPageComment(object);

        res.json(comment);
    }
});


// GET
router.get('/:site/*', utils.limiter(500), (req, res) => {
    const site = req.params.site;
    const path = req.params[0];
    const comments = db.pageComments(site, path);
    res.json(comments);
});
